# coding: utf-8

"""
    wwtp-paas-infrastructure-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_wwtp_infrastructure_service.api_client import ApiClient
from dhicn_wwtp_infrastructure_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class AlarmApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def api_alarm_add_alarm_configs_post(self, **kwargs):  # noqa: E501
        """添加报警配置 Add alarm config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_add_alarm_configs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AlarmConfigInOut] alarm_config_in_out:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_add_alarm_configs_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_add_alarm_configs_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加报警配置 Add alarm config  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_add_alarm_configs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AlarmConfigInOut] alarm_config_in_out:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'alarm_config_in_out'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_add_alarm_configs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'alarm_config_in_out' in local_var_params:
            body_params = local_var_params['alarm_config_in_out']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/AddAlarmConfigs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_add_alarm_logs_post(self, **kwargs):  # noqa: E501
        """添加报警日志 Add alarm logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_add_alarm_logs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AlarmLogInout] alarm_log_inout:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_add_alarm_logs_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_add_alarm_logs_post_with_http_info(self, **kwargs):  # noqa: E501
        """添加报警日志 Add alarm logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_add_alarm_logs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AlarmLogInout] alarm_log_inout:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'alarm_log_inout'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_add_alarm_logs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'alarm_log_inout' in local_var_params:
            body_params = local_var_params['alarm_log_inout']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/AddAlarmLogs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_delete_alarm_configs_post(self, **kwargs):  # noqa: E501
        """根据ID删除报警配置信息 Delete alarm config data by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_delete_alarm_configs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_delete_alarm_configs_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_delete_alarm_configs_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据ID删除报警配置信息 Delete alarm config data by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_delete_alarm_configs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_delete_alarm_configs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/DeleteAlarmConfigs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_delete_alarm_logs_post(self, **kwargs):  # noqa: E501
        """根据ID删除报警日志 Delete alarm logs by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_delete_alarm_logs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_delete_alarm_logs_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_delete_alarm_logs_post_with_http_info(self, **kwargs):  # noqa: E501
        """根据ID删除报警日志 Delete alarm logs by ids  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_delete_alarm_logs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_delete_alarm_logs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/DeleteAlarmLogs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_get_alarm_configs_by_grade_and_indicator_get(self, **kwargs):  # noqa: E501
        """通过等级和指标获取报警配置信息 Get alarm config by grade and indicator  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_configs_by_grade_and_indicator_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int grade: 等级 grade
        :param str indicator: 指标 indicator
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AlarmConfigInOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_get_alarm_configs_by_grade_and_indicator_get_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_get_alarm_configs_by_grade_and_indicator_get_with_http_info(self, **kwargs):  # noqa: E501
        """通过等级和指标获取报警配置信息 Get alarm config by grade and indicator  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_configs_by_grade_and_indicator_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int grade: 等级 grade
        :param str indicator: 指标 indicator
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AlarmConfigInOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'grade',
            'indicator'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_get_alarm_configs_by_grade_and_indicator_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'grade' in local_var_params and local_var_params['grade'] is not None:  # noqa: E501
            query_params.append(('grade', local_var_params['grade']))  # noqa: E501
        if 'indicator' in local_var_params and local_var_params['indicator'] is not None:  # noqa: E501
            query_params.append(('indicator', local_var_params['indicator']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/GetAlarmConfigsByGradeAndIndicator', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AlarmConfigInOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_get_alarm_configs_by_grade_get(self, **kwargs):  # noqa: E501
        """通过等级获取报警配置信息 Get alarm config by grade  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_configs_by_grade_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int grade: 等级 grade
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AlarmConfigInOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_get_alarm_configs_by_grade_get_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_get_alarm_configs_by_grade_get_with_http_info(self, **kwargs):  # noqa: E501
        """通过等级获取报警配置信息 Get alarm config by grade  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_configs_by_grade_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int grade: 等级 grade
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AlarmConfigInOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'grade'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_get_alarm_configs_by_grade_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'grade' in local_var_params and local_var_params['grade'] is not None:  # noqa: E501
            query_params.append(('grade', local_var_params['grade']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/GetAlarmConfigsByGrade', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AlarmConfigInOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_get_alarm_logs_by_condition_post(self, **kwargs):  # noqa: E501
        """通过条件获取报警日志 Get alarm logs by condition  # noqa: E501

        通过时间、报警类型等获取报警日志 Get alarm logs by time and alarm type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_logs_by_condition_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AlarmLogInput alarm_log_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AlarmLogInout]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_get_alarm_logs_by_condition_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_get_alarm_logs_by_condition_post_with_http_info(self, **kwargs):  # noqa: E501
        """通过条件获取报警日志 Get alarm logs by condition  # noqa: E501

        通过时间、报警类型等获取报警日志 Get alarm logs by time and alarm type  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_logs_by_condition_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param AlarmLogInput alarm_log_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AlarmLogInout], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'alarm_log_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_get_alarm_logs_by_condition_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'alarm_log_input' in local_var_params:
            body_params = local_var_params['alarm_log_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/GetAlarmLogsByCondition', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AlarmLogInout]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_get_alarm_logs_by_grade_get(self, **kwargs):  # noqa: E501
        """通过等级获取报警日志 Get alarm logs by grade  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_logs_by_grade_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int grade: 等级 grade
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AlarmLogInout]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_get_alarm_logs_by_grade_get_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_get_alarm_logs_by_grade_get_with_http_info(self, **kwargs):  # noqa: E501
        """通过等级获取报警日志 Get alarm logs by grade  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_alarm_logs_by_grade_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param int grade: 等级 grade
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AlarmLogInout], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'grade'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_get_alarm_logs_by_grade_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'grade' in local_var_params and local_var_params['grade'] is not None:  # noqa: E501
            query_params.append(('grade', local_var_params['grade']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/GetAlarmLogsByGrade', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AlarmLogInout]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_get_all_alarm_configs_get(self, **kwargs):  # noqa: E501
        """获取所有报警配置 Get all alarm config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_all_alarm_configs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AlarmConfigInOut]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_get_all_alarm_configs_get_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_get_all_alarm_configs_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有报警配置 Get all alarm config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_all_alarm_configs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AlarmConfigInOut], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_get_all_alarm_configs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/GetAllAlarmConfigs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AlarmConfigInOut]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_get_all_alarm_logs_get(self, **kwargs):  # noqa: E501
        """获取所有报警日志 Get all alarm logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_all_alarm_logs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[AlarmLogInout]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_get_all_alarm_logs_get_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_get_all_alarm_logs_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取所有报警日志 Get all alarm logs  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_get_all_alarm_logs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[AlarmLogInout], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_get_all_alarm_logs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/GetAllAlarmLogs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[AlarmLogInout]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_judge_dosage_post(self, **kwargs):  # noqa: E501
        """判断加药量，写入报警日志 Write dosing alarm logs based on dosage data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_judge_dosage_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[DosageBasicInfo] dosage_basic_info:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_judge_dosage_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_judge_dosage_post_with_http_info(self, **kwargs):  # noqa: E501
        """判断加药量，写入报警日志 Write dosing alarm logs based on dosage data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_judge_dosage_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[DosageBasicInfo] dosage_basic_info:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'dosage_basic_info'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_judge_dosage_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'dosage_basic_info' in local_var_params:
            body_params = local_var_params['dosage_basic_info']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/JudgeDosage', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def api_alarm_update_alarm_configs_post(self, **kwargs):  # noqa: E501
        """更新报警配置信息 Update alarm config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_update_alarm_configs_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AlarmConfigInOut] alarm_config_in_out:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.api_alarm_update_alarm_configs_post_with_http_info(**kwargs)  # noqa: E501

    def api_alarm_update_alarm_configs_post_with_http_info(self, **kwargs):  # noqa: E501
        """更新报警配置信息 Update alarm config data  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.api_alarm_update_alarm_configs_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[AlarmConfigInOut] alarm_config_in_out:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(object, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'alarm_config_in_out'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method api_alarm_update_alarm_configs_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'alarm_config_in_out' in local_var_params:
            body_params = local_var_params['alarm_config_in_out']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/Alarm/UpdateAlarmConfigs', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='object',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class ConfigurationModel(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'flow_ratio_offset': 'float',
        'weir_height_offset': 'float',
        'flow_ratio_of_factory4': 'float',
        'flow_ratio_of_factory4_lower': 'float',
        'flow_ratio_of_factory4_upper': 'float',
        'q2max': 'float',
        'sum_set2_1': 'float',
        'sum_set2_2': 'float',
        'sum_set2_3': 'float',
        'sum_set2_4': 'float',
        'k_q2_1': 'float',
        'k_q2_2': 'float',
        'k_q2_3': 'float',
        'k_q2_4': 'float',
        'k_q2_5': 'float',
        'd_q2': 'float',
        'q3max': 'float',
        'sum_set3_1': 'float',
        'sum_set3_2': 'float',
        'sum_set3_3': 'float',
        'sum_set3_4': 'float',
        'k_q3_1': 'float',
        'k_q3_2': 'float',
        'k_q3_3': 'float',
        'k_q3_4': 'float',
        'k_q3_5': 'float',
        'd_q3': 'float',
        'q4max': 'float',
        'sum_set4_1': 'float',
        'sum_set4_2': 'float',
        'sum_set4_3': 'float',
        'sum_set4_4': 'float',
        'k_q4_1': 'float',
        'k_q4_2': 'float',
        'k_q4_3': 'float',
        'k_q4_4': 'float',
        'k_q4_5': 'float',
        'd_q4': 'float'
    }

    attribute_map = {
        'flow_ratio_offset': 'flowRatioOffset',
        'weir_height_offset': 'weirHeightOffset',
        'flow_ratio_of_factory4': 'flowRatioOfFactory4',
        'flow_ratio_of_factory4_lower': 'flowRatioOfFactory4Lower',
        'flow_ratio_of_factory4_upper': 'flowRatioOfFactory4Upper',
        'q2max': 'q2max',
        'sum_set2_1': 'sumSet2_1',
        'sum_set2_2': 'sumSet2_2',
        'sum_set2_3': 'sumSet2_3',
        'sum_set2_4': 'sumSet2_4',
        'k_q2_1': 'kQ2_1',
        'k_q2_2': 'kQ2_2',
        'k_q2_3': 'kQ2_3',
        'k_q2_4': 'kQ2_4',
        'k_q2_5': 'kQ2_5',
        'd_q2': 'dQ2',
        'q3max': 'q3max',
        'sum_set3_1': 'sumSet3_1',
        'sum_set3_2': 'sumSet3_2',
        'sum_set3_3': 'sumSet3_3',
        'sum_set3_4': 'sumSet3_4',
        'k_q3_1': 'kQ3_1',
        'k_q3_2': 'kQ3_2',
        'k_q3_3': 'kQ3_3',
        'k_q3_4': 'kQ3_4',
        'k_q3_5': 'kQ3_5',
        'd_q3': 'dQ3',
        'q4max': 'q4max',
        'sum_set4_1': 'sumSet4_1',
        'sum_set4_2': 'sumSet4_2',
        'sum_set4_3': 'sumSet4_3',
        'sum_set4_4': 'sumSet4_4',
        'k_q4_1': 'kQ4_1',
        'k_q4_2': 'kQ4_2',
        'k_q4_3': 'kQ4_3',
        'k_q4_4': 'kQ4_4',
        'k_q4_5': 'kQ4_5',
        'd_q4': 'dQ4'
    }

    def __init__(self, flow_ratio_offset=None, weir_height_offset=None, flow_ratio_of_factory4=None, flow_ratio_of_factory4_lower=None, flow_ratio_of_factory4_upper=None, q2max=None, sum_set2_1=None, sum_set2_2=None, sum_set2_3=None, sum_set2_4=None, k_q2_1=None, k_q2_2=None, k_q2_3=None, k_q2_4=None, k_q2_5=None, d_q2=None, q3max=None, sum_set3_1=None, sum_set3_2=None, sum_set3_3=None, sum_set3_4=None, k_q3_1=None, k_q3_2=None, k_q3_3=None, k_q3_4=None, k_q3_5=None, d_q3=None, q4max=None, sum_set4_1=None, sum_set4_2=None, sum_set4_3=None, sum_set4_4=None, k_q4_1=None, k_q4_2=None, k_q4_3=None, k_q4_4=None, k_q4_5=None, d_q4=None, local_vars_configuration=None):  # noqa: E501
        """ConfigurationModel - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._flow_ratio_offset = None
        self._weir_height_offset = None
        self._flow_ratio_of_factory4 = None
        self._flow_ratio_of_factory4_lower = None
        self._flow_ratio_of_factory4_upper = None
        self._q2max = None
        self._sum_set2_1 = None
        self._sum_set2_2 = None
        self._sum_set2_3 = None
        self._sum_set2_4 = None
        self._k_q2_1 = None
        self._k_q2_2 = None
        self._k_q2_3 = None
        self._k_q2_4 = None
        self._k_q2_5 = None
        self._d_q2 = None
        self._q3max = None
        self._sum_set3_1 = None
        self._sum_set3_2 = None
        self._sum_set3_3 = None
        self._sum_set3_4 = None
        self._k_q3_1 = None
        self._k_q3_2 = None
        self._k_q3_3 = None
        self._k_q3_4 = None
        self._k_q3_5 = None
        self._d_q3 = None
        self._q4max = None
        self._sum_set4_1 = None
        self._sum_set4_2 = None
        self._sum_set4_3 = None
        self._sum_set4_4 = None
        self._k_q4_1 = None
        self._k_q4_2 = None
        self._k_q4_3 = None
        self._k_q4_4 = None
        self._k_q4_5 = None
        self._d_q4 = None
        self.discriminator = None

        if flow_ratio_offset is not None:
            self.flow_ratio_offset = flow_ratio_offset
        if weir_height_offset is not None:
            self.weir_height_offset = weir_height_offset
        if flow_ratio_of_factory4 is not None:
            self.flow_ratio_of_factory4 = flow_ratio_of_factory4
        if flow_ratio_of_factory4_lower is not None:
            self.flow_ratio_of_factory4_lower = flow_ratio_of_factory4_lower
        if flow_ratio_of_factory4_upper is not None:
            self.flow_ratio_of_factory4_upper = flow_ratio_of_factory4_upper
        if q2max is not None:
            self.q2max = q2max
        if sum_set2_1 is not None:
            self.sum_set2_1 = sum_set2_1
        if sum_set2_2 is not None:
            self.sum_set2_2 = sum_set2_2
        if sum_set2_3 is not None:
            self.sum_set2_3 = sum_set2_3
        if sum_set2_4 is not None:
            self.sum_set2_4 = sum_set2_4
        if k_q2_1 is not None:
            self.k_q2_1 = k_q2_1
        if k_q2_2 is not None:
            self.k_q2_2 = k_q2_2
        if k_q2_3 is not None:
            self.k_q2_3 = k_q2_3
        if k_q2_4 is not None:
            self.k_q2_4 = k_q2_4
        if k_q2_5 is not None:
            self.k_q2_5 = k_q2_5
        if d_q2 is not None:
            self.d_q2 = d_q2
        if q3max is not None:
            self.q3max = q3max
        if sum_set3_1 is not None:
            self.sum_set3_1 = sum_set3_1
        if sum_set3_2 is not None:
            self.sum_set3_2 = sum_set3_2
        if sum_set3_3 is not None:
            self.sum_set3_3 = sum_set3_3
        if sum_set3_4 is not None:
            self.sum_set3_4 = sum_set3_4
        if k_q3_1 is not None:
            self.k_q3_1 = k_q3_1
        if k_q3_2 is not None:
            self.k_q3_2 = k_q3_2
        if k_q3_3 is not None:
            self.k_q3_3 = k_q3_3
        if k_q3_4 is not None:
            self.k_q3_4 = k_q3_4
        if k_q3_5 is not None:
            self.k_q3_5 = k_q3_5
        if d_q3 is not None:
            self.d_q3 = d_q3
        if q4max is not None:
            self.q4max = q4max
        if sum_set4_1 is not None:
            self.sum_set4_1 = sum_set4_1
        if sum_set4_2 is not None:
            self.sum_set4_2 = sum_set4_2
        if sum_set4_3 is not None:
            self.sum_set4_3 = sum_set4_3
        if sum_set4_4 is not None:
            self.sum_set4_4 = sum_set4_4
        if k_q4_1 is not None:
            self.k_q4_1 = k_q4_1
        if k_q4_2 is not None:
            self.k_q4_2 = k_q4_2
        if k_q4_3 is not None:
            self.k_q4_3 = k_q4_3
        if k_q4_4 is not None:
            self.k_q4_4 = k_q4_4
        if k_q4_5 is not None:
            self.k_q4_5 = k_q4_5
        if d_q4 is not None:
            self.d_q4 = d_q4

    @property
    def flow_ratio_offset(self):
        """Gets the flow_ratio_offset of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_offset of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_offset

    @flow_ratio_offset.setter
    def flow_ratio_offset(self, flow_ratio_offset):
        """Sets the flow_ratio_offset of this ConfigurationModel.


        :param flow_ratio_offset: The flow_ratio_offset of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_offset = flow_ratio_offset

    @property
    def weir_height_offset(self):
        """Gets the weir_height_offset of this ConfigurationModel.  # noqa: E501


        :return: The weir_height_offset of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._weir_height_offset

    @weir_height_offset.setter
    def weir_height_offset(self, weir_height_offset):
        """Sets the weir_height_offset of this ConfigurationModel.


        :param weir_height_offset: The weir_height_offset of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._weir_height_offset = weir_height_offset

    @property
    def flow_ratio_of_factory4(self):
        """Gets the flow_ratio_of_factory4 of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_of_factory4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_of_factory4

    @flow_ratio_of_factory4.setter
    def flow_ratio_of_factory4(self, flow_ratio_of_factory4):
        """Sets the flow_ratio_of_factory4 of this ConfigurationModel.


        :param flow_ratio_of_factory4: The flow_ratio_of_factory4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_of_factory4 = flow_ratio_of_factory4

    @property
    def flow_ratio_of_factory4_lower(self):
        """Gets the flow_ratio_of_factory4_lower of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_of_factory4_lower of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_of_factory4_lower

    @flow_ratio_of_factory4_lower.setter
    def flow_ratio_of_factory4_lower(self, flow_ratio_of_factory4_lower):
        """Sets the flow_ratio_of_factory4_lower of this ConfigurationModel.


        :param flow_ratio_of_factory4_lower: The flow_ratio_of_factory4_lower of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_of_factory4_lower = flow_ratio_of_factory4_lower

    @property
    def flow_ratio_of_factory4_upper(self):
        """Gets the flow_ratio_of_factory4_upper of this ConfigurationModel.  # noqa: E501


        :return: The flow_ratio_of_factory4_upper of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._flow_ratio_of_factory4_upper

    @flow_ratio_of_factory4_upper.setter
    def flow_ratio_of_factory4_upper(self, flow_ratio_of_factory4_upper):
        """Sets the flow_ratio_of_factory4_upper of this ConfigurationModel.


        :param flow_ratio_of_factory4_upper: The flow_ratio_of_factory4_upper of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._flow_ratio_of_factory4_upper = flow_ratio_of_factory4_upper

    @property
    def q2max(self):
        """Gets the q2max of this ConfigurationModel.  # noqa: E501


        :return: The q2max of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._q2max

    @q2max.setter
    def q2max(self, q2max):
        """Sets the q2max of this ConfigurationModel.


        :param q2max: The q2max of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._q2max = q2max

    @property
    def sum_set2_1(self):
        """Gets the sum_set2_1 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_1

    @sum_set2_1.setter
    def sum_set2_1(self, sum_set2_1):
        """Sets the sum_set2_1 of this ConfigurationModel.


        :param sum_set2_1: The sum_set2_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_1 = sum_set2_1

    @property
    def sum_set2_2(self):
        """Gets the sum_set2_2 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_2

    @sum_set2_2.setter
    def sum_set2_2(self, sum_set2_2):
        """Sets the sum_set2_2 of this ConfigurationModel.


        :param sum_set2_2: The sum_set2_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_2 = sum_set2_2

    @property
    def sum_set2_3(self):
        """Gets the sum_set2_3 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_3

    @sum_set2_3.setter
    def sum_set2_3(self, sum_set2_3):
        """Sets the sum_set2_3 of this ConfigurationModel.


        :param sum_set2_3: The sum_set2_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_3 = sum_set2_3

    @property
    def sum_set2_4(self):
        """Gets the sum_set2_4 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set2_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set2_4

    @sum_set2_4.setter
    def sum_set2_4(self, sum_set2_4):
        """Sets the sum_set2_4 of this ConfigurationModel.


        :param sum_set2_4: The sum_set2_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set2_4 = sum_set2_4

    @property
    def k_q2_1(self):
        """Gets the k_q2_1 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_1

    @k_q2_1.setter
    def k_q2_1(self, k_q2_1):
        """Sets the k_q2_1 of this ConfigurationModel.


        :param k_q2_1: The k_q2_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_1 = k_q2_1

    @property
    def k_q2_2(self):
        """Gets the k_q2_2 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_2

    @k_q2_2.setter
    def k_q2_2(self, k_q2_2):
        """Sets the k_q2_2 of this ConfigurationModel.


        :param k_q2_2: The k_q2_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_2 = k_q2_2

    @property
    def k_q2_3(self):
        """Gets the k_q2_3 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_3

    @k_q2_3.setter
    def k_q2_3(self, k_q2_3):
        """Sets the k_q2_3 of this ConfigurationModel.


        :param k_q2_3: The k_q2_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_3 = k_q2_3

    @property
    def k_q2_4(self):
        """Gets the k_q2_4 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_4

    @k_q2_4.setter
    def k_q2_4(self, k_q2_4):
        """Sets the k_q2_4 of this ConfigurationModel.


        :param k_q2_4: The k_q2_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_4 = k_q2_4

    @property
    def k_q2_5(self):
        """Gets the k_q2_5 of this ConfigurationModel.  # noqa: E501


        :return: The k_q2_5 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q2_5

    @k_q2_5.setter
    def k_q2_5(self, k_q2_5):
        """Sets the k_q2_5 of this ConfigurationModel.


        :param k_q2_5: The k_q2_5 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q2_5 = k_q2_5

    @property
    def d_q2(self):
        """Gets the d_q2 of this ConfigurationModel.  # noqa: E501


        :return: The d_q2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._d_q2

    @d_q2.setter
    def d_q2(self, d_q2):
        """Sets the d_q2 of this ConfigurationModel.


        :param d_q2: The d_q2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._d_q2 = d_q2

    @property
    def q3max(self):
        """Gets the q3max of this ConfigurationModel.  # noqa: E501


        :return: The q3max of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._q3max

    @q3max.setter
    def q3max(self, q3max):
        """Sets the q3max of this ConfigurationModel.


        :param q3max: The q3max of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._q3max = q3max

    @property
    def sum_set3_1(self):
        """Gets the sum_set3_1 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_1

    @sum_set3_1.setter
    def sum_set3_1(self, sum_set3_1):
        """Sets the sum_set3_1 of this ConfigurationModel.


        :param sum_set3_1: The sum_set3_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_1 = sum_set3_1

    @property
    def sum_set3_2(self):
        """Gets the sum_set3_2 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_2

    @sum_set3_2.setter
    def sum_set3_2(self, sum_set3_2):
        """Sets the sum_set3_2 of this ConfigurationModel.


        :param sum_set3_2: The sum_set3_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_2 = sum_set3_2

    @property
    def sum_set3_3(self):
        """Gets the sum_set3_3 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_3

    @sum_set3_3.setter
    def sum_set3_3(self, sum_set3_3):
        """Sets the sum_set3_3 of this ConfigurationModel.


        :param sum_set3_3: The sum_set3_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_3 = sum_set3_3

    @property
    def sum_set3_4(self):
        """Gets the sum_set3_4 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set3_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set3_4

    @sum_set3_4.setter
    def sum_set3_4(self, sum_set3_4):
        """Sets the sum_set3_4 of this ConfigurationModel.


        :param sum_set3_4: The sum_set3_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set3_4 = sum_set3_4

    @property
    def k_q3_1(self):
        """Gets the k_q3_1 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_1

    @k_q3_1.setter
    def k_q3_1(self, k_q3_1):
        """Sets the k_q3_1 of this ConfigurationModel.


        :param k_q3_1: The k_q3_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_1 = k_q3_1

    @property
    def k_q3_2(self):
        """Gets the k_q3_2 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_2

    @k_q3_2.setter
    def k_q3_2(self, k_q3_2):
        """Sets the k_q3_2 of this ConfigurationModel.


        :param k_q3_2: The k_q3_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_2 = k_q3_2

    @property
    def k_q3_3(self):
        """Gets the k_q3_3 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_3

    @k_q3_3.setter
    def k_q3_3(self, k_q3_3):
        """Sets the k_q3_3 of this ConfigurationModel.


        :param k_q3_3: The k_q3_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_3 = k_q3_3

    @property
    def k_q3_4(self):
        """Gets the k_q3_4 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_4

    @k_q3_4.setter
    def k_q3_4(self, k_q3_4):
        """Sets the k_q3_4 of this ConfigurationModel.


        :param k_q3_4: The k_q3_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_4 = k_q3_4

    @property
    def k_q3_5(self):
        """Gets the k_q3_5 of this ConfigurationModel.  # noqa: E501


        :return: The k_q3_5 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q3_5

    @k_q3_5.setter
    def k_q3_5(self, k_q3_5):
        """Sets the k_q3_5 of this ConfigurationModel.


        :param k_q3_5: The k_q3_5 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q3_5 = k_q3_5

    @property
    def d_q3(self):
        """Gets the d_q3 of this ConfigurationModel.  # noqa: E501


        :return: The d_q3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._d_q3

    @d_q3.setter
    def d_q3(self, d_q3):
        """Sets the d_q3 of this ConfigurationModel.


        :param d_q3: The d_q3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._d_q3 = d_q3

    @property
    def q4max(self):
        """Gets the q4max of this ConfigurationModel.  # noqa: E501


        :return: The q4max of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._q4max

    @q4max.setter
    def q4max(self, q4max):
        """Sets the q4max of this ConfigurationModel.


        :param q4max: The q4max of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._q4max = q4max

    @property
    def sum_set4_1(self):
        """Gets the sum_set4_1 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_1

    @sum_set4_1.setter
    def sum_set4_1(self, sum_set4_1):
        """Sets the sum_set4_1 of this ConfigurationModel.


        :param sum_set4_1: The sum_set4_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_1 = sum_set4_1

    @property
    def sum_set4_2(self):
        """Gets the sum_set4_2 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_2

    @sum_set4_2.setter
    def sum_set4_2(self, sum_set4_2):
        """Sets the sum_set4_2 of this ConfigurationModel.


        :param sum_set4_2: The sum_set4_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_2 = sum_set4_2

    @property
    def sum_set4_3(self):
        """Gets the sum_set4_3 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_3

    @sum_set4_3.setter
    def sum_set4_3(self, sum_set4_3):
        """Sets the sum_set4_3 of this ConfigurationModel.


        :param sum_set4_3: The sum_set4_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_3 = sum_set4_3

    @property
    def sum_set4_4(self):
        """Gets the sum_set4_4 of this ConfigurationModel.  # noqa: E501


        :return: The sum_set4_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._sum_set4_4

    @sum_set4_4.setter
    def sum_set4_4(self, sum_set4_4):
        """Sets the sum_set4_4 of this ConfigurationModel.


        :param sum_set4_4: The sum_set4_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._sum_set4_4 = sum_set4_4

    @property
    def k_q4_1(self):
        """Gets the k_q4_1 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_1 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_1

    @k_q4_1.setter
    def k_q4_1(self, k_q4_1):
        """Sets the k_q4_1 of this ConfigurationModel.


        :param k_q4_1: The k_q4_1 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_1 = k_q4_1

    @property
    def k_q4_2(self):
        """Gets the k_q4_2 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_2 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_2

    @k_q4_2.setter
    def k_q4_2(self, k_q4_2):
        """Sets the k_q4_2 of this ConfigurationModel.


        :param k_q4_2: The k_q4_2 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_2 = k_q4_2

    @property
    def k_q4_3(self):
        """Gets the k_q4_3 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_3 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_3

    @k_q4_3.setter
    def k_q4_3(self, k_q4_3):
        """Sets the k_q4_3 of this ConfigurationModel.


        :param k_q4_3: The k_q4_3 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_3 = k_q4_3

    @property
    def k_q4_4(self):
        """Gets the k_q4_4 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_4

    @k_q4_4.setter
    def k_q4_4(self, k_q4_4):
        """Sets the k_q4_4 of this ConfigurationModel.


        :param k_q4_4: The k_q4_4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_4 = k_q4_4

    @property
    def k_q4_5(self):
        """Gets the k_q4_5 of this ConfigurationModel.  # noqa: E501


        :return: The k_q4_5 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._k_q4_5

    @k_q4_5.setter
    def k_q4_5(self, k_q4_5):
        """Sets the k_q4_5 of this ConfigurationModel.


        :param k_q4_5: The k_q4_5 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._k_q4_5 = k_q4_5

    @property
    def d_q4(self):
        """Gets the d_q4 of this ConfigurationModel.  # noqa: E501


        :return: The d_q4 of this ConfigurationModel.  # noqa: E501
        :rtype: float
        """
        return self._d_q4

    @d_q4.setter
    def d_q4(self, d_q4):
        """Sets the d_q4 of this ConfigurationModel.


        :param d_q4: The d_q4 of this ConfigurationModel.  # noqa: E501
        :type: float
        """

        self._d_q4 = d_q4

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ConfigurationModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ConfigurationModel):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    竹园污水项目

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_zyws_service.configuration import Configuration


class OrificeControlResultOutput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'control_model_id': 'str',
        't': 'list[str]',
        'gate_level': 'DataResult',
        'discharge_in_structure': 'DataResult',
        'static_height': 'float'
    }

    attribute_map = {
        'control_model_id': 'controlModelId',
        't': 't',
        'gate_level': 'gateLevel',
        'discharge_in_structure': 'dischargeInStructure',
        'static_height': 'staticHeight'
    }

    def __init__(self, control_model_id=None, t=None, gate_level=None, discharge_in_structure=None, static_height=None, local_vars_configuration=None):  # noqa: E501
        """OrificeControlResultOutput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._control_model_id = None
        self._t = None
        self._gate_level = None
        self._discharge_in_structure = None
        self._static_height = None
        self.discriminator = None

        self.control_model_id = control_model_id
        self.t = t
        if gate_level is not None:
            self.gate_level = gate_level
        if discharge_in_structure is not None:
            self.discharge_in_structure = discharge_in_structure
        if static_height is not None:
            self.static_height = static_height

    @property
    def control_model_id(self):
        """Gets the control_model_id of this OrificeControlResultOutput.  # noqa: E501

        微调堰  # noqa: E501

        :return: The control_model_id of this OrificeControlResultOutput.  # noqa: E501
        :rtype: str
        """
        return self._control_model_id

    @control_model_id.setter
    def control_model_id(self, control_model_id):
        """Sets the control_model_id of this OrificeControlResultOutput.

        微调堰  # noqa: E501

        :param control_model_id: The control_model_id of this OrificeControlResultOutput.  # noqa: E501
        :type: str
        """

        self._control_model_id = control_model_id

    @property
    def t(self):
        """Gets the t of this OrificeControlResultOutput.  # noqa: E501

        方案  # noqa: E501

        :return: The t of this OrificeControlResultOutput.  # noqa: E501
        :rtype: list[str]
        """
        return self._t

    @t.setter
    def t(self, t):
        """Sets the t of this OrificeControlResultOutput.

        方案  # noqa: E501

        :param t: The t of this OrificeControlResultOutput.  # noqa: E501
        :type: list[str]
        """

        self._t = t

    @property
    def gate_level(self):
        """Gets the gate_level of this OrificeControlResultOutput.  # noqa: E501


        :return: The gate_level of this OrificeControlResultOutput.  # noqa: E501
        :rtype: DataResult
        """
        return self._gate_level

    @gate_level.setter
    def gate_level(self, gate_level):
        """Sets the gate_level of this OrificeControlResultOutput.


        :param gate_level: The gate_level of this OrificeControlResultOutput.  # noqa: E501
        :type: DataResult
        """

        self._gate_level = gate_level

    @property
    def discharge_in_structure(self):
        """Gets the discharge_in_structure of this OrificeControlResultOutput.  # noqa: E501


        :return: The discharge_in_structure of this OrificeControlResultOutput.  # noqa: E501
        :rtype: DataResult
        """
        return self._discharge_in_structure

    @discharge_in_structure.setter
    def discharge_in_structure(self, discharge_in_structure):
        """Sets the discharge_in_structure of this OrificeControlResultOutput.


        :param discharge_in_structure: The discharge_in_structure of this OrificeControlResultOutput.  # noqa: E501
        :type: DataResult
        """

        self._discharge_in_structure = discharge_in_structure

    @property
    def static_height(self):
        """Gets the static_height of this OrificeControlResultOutput.  # noqa: E501

        常开固定堰的高度  # noqa: E501

        :return: The static_height of this OrificeControlResultOutput.  # noqa: E501
        :rtype: float
        """
        return self._static_height

    @static_height.setter
    def static_height(self, static_height):
        """Sets the static_height of this OrificeControlResultOutput.

        常开固定堰的高度  # noqa: E501

        :param static_height: The static_height of this OrificeControlResultOutput.  # noqa: E501
        :type: float
        """

        self._static_height = static_height

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrificeControlResultOutput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrificeControlResultOutput):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    model-driver-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from dhicn_model_driver_service.api_client import ApiClient
from dhicn_model_driver_service.exceptions import (  # noqa: F401
    ApiTypeError,
    ApiValueError
)


class ModelRunApi(object):
    """NOTE: This class is auto generated by OpenAPI Generator
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def model_run_cancel_model_run_post(self, **kwargs):  # noqa: E501
        """【废弃】取消模型计算 Cancel model run  # noqa: E501

        取消计算方案模型的任务 Cancel the task to run the model of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_cancel_model_run_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ScenarioModelMessageInput scenario_model_message_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ModelOperationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_cancel_model_run_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_cancel_model_run_post_with_http_info(self, **kwargs):  # noqa: E501
        """【废弃】取消模型计算 Cancel model run  # noqa: E501

        取消计算方案模型的任务 Cancel the task to run the model of a scenario.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_cancel_model_run_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ScenarioModelMessageInput scenario_model_message_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ModelOperationResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_model_message_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_cancel_model_run_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'scenario_model_message_input' in local_var_params:
            body_params = local_var_params['scenario_model_message_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/CancelModelRun', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelOperationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_get_queue_message_count_post(self, **kwargs):  # noqa: E501
        """获取计算队列的长度 Get model running queue length  # noqa: E501

        获取当前模型计算队列的长度 Get current model running queue length  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_get_queue_message_count_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelTypePara model_type_para:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: int
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_get_queue_message_count_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_get_queue_message_count_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取计算队列的长度 Get model running queue length  # noqa: E501

        获取当前模型计算队列的长度 Get current model running queue length  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_get_queue_message_count_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelTypePara model_type_para:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(int, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_type_para'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_get_queue_message_count_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_type_para' in local_var_params:
            body_params = local_var_params['model_type_para']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/GetQueueMessageCount', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='int',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_get_runing_scenario_get(self, **kwargs):  # noqa: E501
        """查询正在计算的方案信息 Get scenario information which is running  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_get_runing_scenario_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_name: 项目名称 project name
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ScenarioModelMessage]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_get_runing_scenario_get_with_http_info(**kwargs)  # noqa: E501

    def model_run_get_runing_scenario_get_with_http_info(self, **kwargs):  # noqa: E501
        """查询正在计算的方案信息 Get scenario information which is running  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_get_runing_scenario_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_name: 项目名称 project name
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ScenarioModelMessage], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_name'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_get_runing_scenario_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'project_name' in local_var_params and local_var_params['project_name'] is not None:  # noqa: E501
            query_params.append(('projectName', local_var_params['project_name']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/GetRuningScenario', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ScenarioModelMessage]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_get_scenarioes_status_post(self, **kwargs):  # noqa: E501
        """获取方案的状态 Get scenario’s status  # noqa: E501

        批量获取方案的计算状态 Get scenarios’s model running status in batch mode  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_get_scenarioes_status_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ScenarioIds scenario_ids:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ScenarioModelStatusMessage]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_get_scenarioes_status_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_get_scenarioes_status_post_with_http_info(self, **kwargs):  # noqa: E501
        """获取方案的状态 Get scenario’s status  # noqa: E501

        批量获取方案的计算状态 Get scenarios’s model running status in batch mode  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_get_scenarioes_status_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ScenarioIds scenario_ids:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ScenarioModelStatusMessage], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_ids'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_get_scenarioes_status_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'scenario_ids' in local_var_params:
            body_params = local_var_params['scenario_ids']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/GetScenarioesStatus', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ScenarioModelStatusMessage]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_query_compute_resource_info_post(self, **kwargs):  # noqa: E501
        """查询计算资源信息 Query compute resource info  # noqa: E501

        查询计算资源信息，返回可用的计算服务器个数，以及对应的队列长度 Get compute resource information, return available compute services’count and corresponding queue length  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_query_compute_resource_info_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelTypePara model_type_para:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: dict(str, str)
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_query_compute_resource_info_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_query_compute_resource_info_post_with_http_info(self, **kwargs):  # noqa: E501
        """查询计算资源信息 Query compute resource info  # noqa: E501

        查询计算资源信息，返回可用的计算服务器个数，以及对应的队列长度 Get compute resource information, return available compute services’count and corresponding queue length  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_query_compute_resource_info_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ModelTypePara model_type_para:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(dict(str, str), status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'model_type_para'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_query_compute_resource_info_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'model_type_para' in local_var_params:
            body_params = local_var_params['model_type_para']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/QueryComputeResourceInfo', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='dict(str, str)',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_query_model_run_status_get(self, **kwargs):  # noqa: E501
        """查询模型计算状态 Query model running status  # noqa: E501

        查询方案模型计算状态（仅针对计算中的模型），所有状态都在枚举类型ModelState中 Get model running status of a scenario (only for model in running), all the status is listed in the Enum ModelState.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_query_model_run_status_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ProjectScenario project_scenario:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ScenarioModelStatusMessage
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_query_model_run_status_get_with_http_info(**kwargs)  # noqa: E501

    def model_run_query_model_run_status_get_with_http_info(self, **kwargs):  # noqa: E501
        """查询模型计算状态 Query model running status  # noqa: E501

        查询方案模型计算状态（仅针对计算中的模型），所有状态都在枚举类型ModelState中 Get model running status of a scenario (only for model in running), all the status is listed in the Enum ModelState.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_query_model_run_status_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ProjectScenario project_scenario:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ScenarioModelStatusMessage, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_scenario'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_query_model_run_status_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'project_scenario' in local_var_params:
            body_params = local_var_params['project_scenario']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/QueryModelRunStatus', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ScenarioModelStatusMessage',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_query_queues_get(self, **kwargs):  # noqa: E501
        """获取排队情况  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_query_queues_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_name: 项目名称 project name
        :param str scenario_id: 方案Id
        :param str model_type: 模型类型
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[ModelDriverDto]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_query_queues_get_with_http_info(**kwargs)  # noqa: E501

    def model_run_query_queues_get_with_http_info(self, **kwargs):  # noqa: E501
        """获取排队情况  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_query_queues_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str project_name: 项目名称 project name
        :param str scenario_id: 方案Id
        :param str model_type: 模型类型
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[ModelDriverDto], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'project_name',
            'scenario_id',
            'model_type'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_query_queues_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'project_name' in local_var_params and local_var_params['project_name'] is not None:  # noqa: E501
            query_params.append(('ProjectName', local_var_params['project_name']))  # noqa: E501
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('ScenarioId', local_var_params['scenario_id']))  # noqa: E501
        if 'model_type' in local_var_params and local_var_params['model_type'] is not None:  # noqa: E501
            query_params.append(('ModelType', local_var_params['model_type']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/QueryQueues', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[ModelDriverDto]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_run_model_post(self, **kwargs):  # noqa: E501
        """[第一步]驱动计算 Start to run a model  # noqa: E501

        创建一个方案模型计算的任务，任务将被推送到一个队列中排队进行计算，能够同时执行计算任务的个数取决于计算服务器个数，以及MIKE狗的个数 Generate a task to run the model of a scenario, which will be put in a queue and wait for it’s turn to run. The number of tasks can be run simultaneously depends on the number of compute services and MIKE dongles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_run_model_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ScenarioModelMessageInput scenario_model_message_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ModelOperationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_run_model_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_run_model_post_with_http_info(self, **kwargs):  # noqa: E501
        """[第一步]驱动计算 Start to run a model  # noqa: E501

        创建一个方案模型计算的任务，任务将被推送到一个队列中排队进行计算，能够同时执行计算任务的个数取决于计算服务器个数，以及MIKE狗的个数 Generate a task to run the model of a scenario, which will be put in a queue and wait for it’s turn to run. The number of tasks can be run simultaneously depends on the number of compute services and MIKE dongles.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_run_model_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param ScenarioModelMessageInput scenario_model_message_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ModelOperationResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_model_message_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_run_model_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'scenario_model_message_input' in local_var_params:
            body_params = local_var_params['scenario_model_message_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/RunModel', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelOperationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_v2_calculate_logs_get(self, **kwargs):  # noqa: E501
        """[第三步]获取方案计算日志  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_calculate_logs_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CalculateLogsOutput
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_v2_calculate_logs_get_with_http_info(**kwargs)  # noqa: E501

    def model_run_v2_calculate_logs_get_with_http_info(self, **kwargs):  # noqa: E501
        """[第三步]获取方案计算日志  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_calculate_logs_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str scenario_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CalculateLogsOutput, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'scenario_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_v2_calculate_logs_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'scenario_id' in local_var_params and local_var_params['scenario_id'] is not None:  # noqa: E501
            query_params.append(('scenarioId', local_var_params['scenario_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/v2/CalculateLogs', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CalculateLogsOutput',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_v2_calculate_status_post(self, **kwargs):  # noqa: E501
        """[第二步]获取方案计算状态（对于等待中的方案，返回其排队序号）  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_calculate_status_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: list[CalculateStatusOutput]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_v2_calculate_status_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_v2_calculate_status_post_with_http_info(self, **kwargs):  # noqa: E501
        """[第二步]获取方案计算状态（对于等待中的方案，返回其排队序号）  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_calculate_status_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(list[CalculateStatusOutput], status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_v2_calculate_status_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/v2/CalculateStatus', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='list[CalculateStatusOutput]',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_v2_cancel_model_run_get(self, **kwargs):  # noqa: E501
        """取消计算通过queueId Cancel model run  # noqa: E501

        取消计算通过queueId Cancelling the computation through queueId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_cancel_model_run_get(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str queue_id:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: ModelOperationResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_v2_cancel_model_run_get_with_http_info(**kwargs)  # noqa: E501

    def model_run_v2_cancel_model_run_get_with_http_info(self, **kwargs):  # noqa: E501
        """取消计算通过queueId Cancel model run  # noqa: E501

        取消计算通过queueId Cancelling the computation through queueId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_cancel_model_run_get_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param str queue_id:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(ModelOperationResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'queue_id'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_v2_cancel_model_run_get" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'queue_id' in local_var_params and local_var_params['queue_id'] is not None:  # noqa: E501
            query_params.append(('queueId', local_var_params['queue_id']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/v2/CancelModelRun', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='ModelOperationResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_v2_cancel_model_run_through_scenario_ids_post(self, **kwargs):  # noqa: E501
        """取消计算通过scenarioId Cancel model run  # noqa: E501

        取消计算通过scenarioId Cancelling the computation through queueId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_cancel_model_run_through_scenario_ids_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: CancelResult
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_v2_cancel_model_run_through_scenario_ids_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_v2_cancel_model_run_through_scenario_ids_post_with_http_info(self, **kwargs):  # noqa: E501
        """取消计算通过scenarioId Cancel model run  # noqa: E501

        取消计算通过scenarioId Cancelling the computation through queueId.  # noqa: E501
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_cancel_model_run_through_scenario_ids_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param list[str] request_body:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(CancelResult, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'request_body'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_v2_cancel_model_run_through_scenario_ids_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'request_body' in local_var_params:
            body_params = local_var_params['request_body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/v2/CancelModelRun/Through/ScenarioIds', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='CancelResult',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)

    def model_run_v2_update_record_post(self, **kwargs):  # noqa: E501
        """通过方案ID来更新minIO地址（后端内部调用）  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_update_record_post(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateRecordInput update_record_input:
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: bool
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        return self.model_run_v2_update_record_post_with_http_info(**kwargs)  # noqa: E501

    def model_run_v2_update_record_post_with_http_info(self, **kwargs):  # noqa: E501
        """通过方案ID来更新minIO地址（后端内部调用）  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.model_run_v2_update_record_post_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool: execute request asynchronously
        :param UpdateRecordInput update_record_input:
        :param _return_http_data_only: response data without head status code
                                       and headers
        :param _preload_content: if False, the urllib3.HTTPResponse object will
                                 be returned without reading/decoding response
                                 data. Default is True.
        :param _request_timeout: timeout setting for this request. If one
                                 number provided, it will be total request
                                 timeout. It can also be a pair (tuple) of
                                 (connection, read) timeouts.
        :return: tuple(bool, status_code(int), headers(HTTPHeaderDict))
                 If the method is called asynchronously,
                 returns the request thread.
        """

        local_var_params = locals()

        all_params = [
            'update_record_input'
        ]
        all_params.extend(
            [
                'async_req',
                '_return_http_data_only',
                '_preload_content',
                '_request_timeout'
            ]
        )

        for key, val in six.iteritems(local_var_params['kwargs']):
            if key not in all_params:
                raise ApiTypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method model_run_v2_update_record_post" % key
                )
            local_var_params[key] = val
        del local_var_params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'update_record_input' in local_var_params:
            body_params = local_var_params['update_record_input']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['application/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/ModelRun/v2/UpdateRecord', 'POST',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='bool',  # noqa: E501
            auth_settings=auth_settings,
            async_req=local_var_params.get('async_req'),
            _return_http_data_only=local_var_params.get('_return_http_data_only'),  # noqa: E501
            _preload_content=local_var_params.get('_preload_content', True),
            _request_timeout=local_var_params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    scenario-manager-service

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


import pprint
import re  # noqa: F401

import six

from dhicn_scenario_manager_service.configuration import Configuration


class CreateTemplateScenarioByMinIoPara2(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'min_io_path': 'str',
        'min_io_bucket': 'str',
        'project_file': 'str',
        'type': 'ModelTypeEnum',
        'group_id': 'str',
        'new_template_name': 'str',
        'sub_type': 'str',
        'description': 'str'
    }

    attribute_map = {
        'min_io_path': 'minIOPath',
        'min_io_bucket': 'minIOBucket',
        'project_file': 'projectFile',
        'type': 'type',
        'group_id': 'groupId',
        'new_template_name': 'newTemplateName',
        'sub_type': 'subType',
        'description': 'description'
    }

    def __init__(self, min_io_path=None, min_io_bucket=None, project_file=None, type=None, group_id=None, new_template_name=None, sub_type=None, description=None, local_vars_configuration=None):  # noqa: E501
        """CreateTemplateScenarioByMinIoPara2 - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration()
        self.local_vars_configuration = local_vars_configuration

        self._min_io_path = None
        self._min_io_bucket = None
        self._project_file = None
        self._type = None
        self._group_id = None
        self._new_template_name = None
        self._sub_type = None
        self._description = None
        self.discriminator = None

        self.min_io_path = min_io_path
        self.min_io_bucket = min_io_bucket
        self.project_file = project_file
        if type is not None:
            self.type = type
        self.group_id = group_id
        self.new_template_name = new_template_name
        self.sub_type = sub_type
        self.description = description

    @property
    def min_io_path(self):
        """Gets the min_io_path of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        模型文件在分布式文件系统上的路径 path of the model file on distributed file system  # noqa: E501

        :return: The min_io_path of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._min_io_path

    @min_io_path.setter
    def min_io_path(self, min_io_path):
        """Sets the min_io_path of this CreateTemplateScenarioByMinIoPara2.

        模型文件在分布式文件系统上的路径 path of the model file on distributed file system  # noqa: E501

        :param min_io_path: The min_io_path of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._min_io_path = min_io_path

    @property
    def min_io_bucket(self):
        """Gets the min_io_bucket of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        模型文件在分布式文件系统上的桶 bucket of the model file on distributed file system  # noqa: E501

        :return: The min_io_bucket of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._min_io_bucket

    @min_io_bucket.setter
    def min_io_bucket(self, min_io_bucket):
        """Sets the min_io_bucket of this CreateTemplateScenarioByMinIoPara2.

        模型文件在分布式文件系统上的桶 bucket of the model file on distributed file system  # noqa: E501

        :param min_io_bucket: The min_io_bucket of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._min_io_bucket = min_io_bucket

    @property
    def project_file(self):
        """Gets the project_file of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        主模型文件相对于模型文件夹的路径 main model file's (eg. .mupp file) relative path to the model folder  # noqa: E501

        :return: The project_file of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._project_file

    @project_file.setter
    def project_file(self, project_file):
        """Sets the project_file of this CreateTemplateScenarioByMinIoPara2.

        主模型文件相对于模型文件夹的路径 main model file's (eg. .mupp file) relative path to the model folder  # noqa: E501

        :param project_file: The project_file of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._project_file = project_file

    @property
    def type(self):
        """Gets the type of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501


        :return: The type of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: ModelTypeEnum
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CreateTemplateScenarioByMinIoPara2.


        :param type: The type of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: ModelTypeEnum
        """

        self._type = type

    @property
    def group_id(self):
        """Gets the group_id of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        模板的方案组ID template scenario's group Id  # noqa: E501

        :return: The group_id of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._group_id

    @group_id.setter
    def group_id(self, group_id):
        """Sets the group_id of this CreateTemplateScenarioByMinIoPara2.

        模板的方案组ID template scenario's group Id  # noqa: E501

        :param group_id: The group_id of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._group_id = group_id

    @property
    def new_template_name(self):
        """Gets the new_template_name of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        模板方案名称 template scenario name  # noqa: E501

        :return: The new_template_name of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._new_template_name

    @new_template_name.setter
    def new_template_name(self, new_template_name):
        """Sets the new_template_name of this CreateTemplateScenarioByMinIoPara2.

        模板方案名称 template scenario name  # noqa: E501

        :param new_template_name: The new_template_name of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._new_template_name = new_template_name

    @property
    def sub_type(self):
        """Gets the sub_type of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        模板方案子类型 template scenario subtype  # noqa: E501

        :return: The sub_type of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._sub_type

    @sub_type.setter
    def sub_type(self, sub_type):
        """Sets the sub_type of this CreateTemplateScenarioByMinIoPara2.

        模板方案子类型 template scenario subtype  # noqa: E501

        :param sub_type: The sub_type of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._sub_type = sub_type

    @property
    def description(self):
        """Gets the description of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501

        模板方案描述 template scenario description  # noqa: E501

        :return: The description of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CreateTemplateScenarioByMinIoPara2.

        模板方案描述 template scenario description  # noqa: E501

        :param description: The description of this CreateTemplateScenarioByMinIoPara2.  # noqa: E501
        :type: str
        """

        self._description = description

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CreateTemplateScenarioByMinIoPara2):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CreateTemplateScenarioByMinIoPara2):
            return True

        return self.to_dict() != other.to_dict()



from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from dhicn_model_information_service.api.da_config_api import DAConfigApi
from dhicn_model_information_service.api.initial_data_api import InitialDataApi
from dhicn_model_information_service.api.model_edit_api import ModelEditApi
from dhicn_model_information_service.api.scenario_code_convert_api import ScenarioCodeConvertApi
from dhicn_model_information_service.api.scenario_operation_api import ScenarioOperationApi
from dhicn_model_information_service.api.user_api import UserApi
from dhicn_model_information_service.api.wd_demand_api import WDDemandApi
from dhicn_model_information_service.api.wd_junction_api import WDJunctionApi
from dhicn_model_information_service.api.wd_model_edit_api import WDModelEditApi
from dhicn_model_information_service.api.wd_pipe_api import WDPipeApi
from dhicn_model_information_service.api.wd_pump_api import WDPumpApi
from dhicn_model_information_service.api.wd_tank_api import WDTankApi
from dhicn_model_information_service.api.wd_valve_api import WDValveApi
